@@ -67,9 +67,9 @@ def test_xml_result(result, expected, encoding=ENCODING):
 
     Parameters
     ----------
-    result: str
+    result: bytes
         The result of running the test.
-    expected: str
+    expected: bytes
         The expected outcome.
 
     Returns
@@ -94,7 +94,7 @@ def test_xml_result(result, expected, encoding=ENCODING):
 
     try:
         result_element = etree.fromstring(result)
-        expected_element = etree.fromstring(expected.encode(encoding))
+        expected_element = etree.fromstring(expected)
         result_buffer = BytesIO()
         result_tree = result_element.getroottree()
         objectify.deannotate(result_tree, cleanup_namespaces=True)
@@ -121,9 +121,9 @@ def test_json_result(result, expected, encoding=ENCODING):
 
     Parameters
     ----------
-    result: str
+    result: bytes
         The result of running the test.
-    expected: str
+    expected: bytes
         The expected outcome.
 
     Returns
@@ -134,8 +134,8 @@ def test_json_result(result, expected, encoding=ENCODING):
     """
 
     try:
-        result_dict = json.loads(result.decode(encoding), encoding=encoding)
-        expected_dict = json.loads(expected, encoding=encoding)
+        result_dict = json.loads(result.decode(encoding))
+        expected_dict = json.loads(expected.decode(encoding))
     except ValueError:
         matches = None
     else:
@@ -153,9 +153,9 @@ def get_validity(expected_path, result, output_file_name, force_id_mask=False):
 
     Parameters
     ----------
-    expected_path: str
+    expected_path: bytes
         The path to the file that has the expected test outcome
-    result: str
+    result: bytes
         The actual result that was generated by running the test code
     output_file_name: str
         Name of the file that will be written to disk with the contents of
@@ -179,11 +179,11 @@ def get_validity(expected_path, result, output_file_name, force_id_mask=False):
 
     normalized_result = normalize(result, force_id_mask=force_id_mask)
     if not os.path.exists(expected_path):  # create expected file
-        with codecs.open(expected_path, 'w', encoding=ENCODING) as f:
+        with open(expected_path, 'wb') as f:
             f.write(normalized_result)
         status = 0
     else:  # compare result with expected
-        with codecs.open(expected_path, encoding=ENCODING) as expected_fh:
+        with open(expected_path, 'rb') as expected_fh:
             expected = expected_fh.read()
             matches_expected = test_xml_result(normalized_result, expected)
             if matches_expected is None:
@@ -204,7 +204,7 @@ def get_validity(expected_path, result, output_file_name, force_id_mask=False):
 def pedantic_get_validity(sexpected, sresult, soutfile, force_id_mask=False):
     """Decipher whether the output passes, fails, or initializes"""
     if not os.path.exists(sexpected):  # create expected file
-        with open(sexpected, 'w') as f:
+        with open(sexpected, 'wb') as f:
             f.write(normalize(sresult, force_id_mask))
         sstatus = 0
     else:  # compare result with expected
@@ -217,9 +217,8 @@ def pedantic_get_validity(sexpected, sresult, soutfile, force_id_mask=False):
             sstatus = 1
         else:  # fail
             import difflib
-            with codecs.open(sexpected, encoding=ENCODING) as a:
-                with codecs.open('results%s%s' % (os.sep, soutfile),
-                                 encoding=ENCODING) as b:
+            with open(sexpected, 'rb') as a:
+                with open('results%s%s' % (os.sep, soutfile), 'rb') as b:
                     a2 = a.readlines()
                     b2 = b.readlines()
                     diff = difflib.unified_diff(a2, b2)
@@ -445,6 +444,9 @@ for testsuite in TESTSUITES_LIST:
                     if os.path.splitext(sfile)[1] not in ['.xml', '.txt']:
                         break
 
+                    if os.path.basename(root) == "exports":
+                        continue
+
                     if sfile == 'requests.txt':  # GET requests
                         filename = '%s%s%s' % (root, os.sep, sfile)
                         with open(filename) as f:
@@ -515,8 +517,8 @@ for testsuite in TESTSUITES_LIST:
                         print('\n test %s' % testfile)
 
                         # read test
-                        with codecs.open(testfile, encoding=ENCODING) as fh:
-                            request = fh.read().encode(ENCODING)
+                        with open(testfile, 'rb') as fh:
+                            request = fh.read()
 
                         configkvp = 'config=tests%s%s' % (os.sep, cfg)
                         url2 = '%s?%s' % (URL, configkvp)
